@@ -11,11 +11,12 @@ pub struct RtcConfig {
     pub ice_servers: Vec<CString>,
     #[derivative(Debug = "ignore")]
     ice_servers_ptrs: Vec<*const c_char>,
+    pub proxy_server: Option<CString>,
     pub bind_address: Option<CString>,
     pub certificate_type: CertificateType,
     pub ice_transport_policy: TransportPolicy,
     pub enable_ice_tcp: bool,
-    // pub enable_ice_udp_mux: bool,
+    pub enable_ice_udp_mux: bool,
     pub port_range_begin: u16,
     pub port_range_end: u16,
     pub mtu: i32,
@@ -37,11 +38,12 @@ impl RtcConfig {
         RtcConfig {
             ice_servers,
             ice_servers_ptrs,
+            proxy_server: None,
             bind_address: None,
             certificate_type: CertificateType::Default,
             ice_transport_policy: TransportPolicy::All,
             enable_ice_tcp: false,
-            // enable_ice_udp_mux: false,
+            enable_ice_udp_mux: false,
             port_range_begin: 0,
             port_range_end: 0,
             mtu: 0,
@@ -55,6 +57,11 @@ impl RtcConfig {
         self
     }
 
+    pub fn proxy_server<S: AsRef<str>>(mut self, server: &S) -> Self {
+        self.proxy_server = Some(CString::new(server.as_ref()).unwrap());
+        self
+    }
+
     pub fn certificate_type(mut self, certificate_type: CertificateType) -> Self {
         self.certificate_type = certificate_type;
         self
@@ -65,10 +72,10 @@ impl RtcConfig {
         self
     }
 
-    // pub fn enable_ice_udp_mux(mut self) -> Self {
-    //     self.enable_ice_udp_mux = true;
-    //     self
-    // }
+    pub fn enable_ice_udp_mux(mut self) -> Self {
+        self.enable_ice_udp_mux = true;
+        self
+    }
 
     pub fn ice_transport_policy(mut self, ice_transport_policy: TransportPolicy) -> Self {
         self.ice_transport_policy = ice_transport_policy;
@@ -99,6 +106,11 @@ impl RtcConfig {
         sys::rtcConfiguration {
             iceServers: self.ice_servers_ptrs.as_ptr() as *mut *const c_char,
             iceServersCount: self.ice_servers.len() as i32,
+            proxyServer: self
+                .proxy_server
+                .as_ref()
+                .map(|addr| addr.as_ptr())
+                .unwrap_or(ptr::null()) as *const c_char,
             bindAddress: self
                 .bind_address
                 .as_ref()
@@ -107,7 +119,7 @@ impl RtcConfig {
             certificateType: self.certificate_type as _,
             iceTransportPolicy: self.ice_transport_policy as _,
             enableIceTcp: self.enable_ice_tcp,
-            // enableIceUdpMux: self.enable_ice_udp_mux,
+            enableIceUdpMux: self.enable_ice_udp_mux,
             disableAutoNegotiation: self.disable_auto_negotiation,
             portRangeBegin: self.port_range_begin,
             portRangeEnd: self.port_range_end,
@@ -124,11 +136,12 @@ impl Clone for RtcConfig {
         RtcConfig {
             ice_servers,
             ice_servers_ptrs,
+            proxy_server: self.proxy_server.clone(),
             bind_address: self.bind_address.clone(),
             certificate_type: self.certificate_type,
             ice_transport_policy: self.ice_transport_policy,
             enable_ice_tcp: self.enable_ice_tcp,
-            // enable_ice_udp_mux: self.enable_ice_udp_mux,
+            enable_ice_udp_mux: self.enable_ice_udp_mux,
             disable_auto_negotiation: self.disable_auto_negotiation,
             port_range_begin: self.port_range_begin,
             port_range_end: self.port_range_end,
@@ -139,8 +152,8 @@ impl Clone for RtcConfig {
 }
 
 #[derive(Debug, PartialEq, Clone, Copy)]
-#[cfg_attr(not(target_os = "windows"), repr(u32))]
-#[cfg_attr(target_os = "windows", repr(i32))]
+#[cfg_attr(any(not(target_os = "windows"), target_env = "gnu"), repr(u32))]
+#[cfg_attr(all(target_os = "windows", not(target_env = "gnu")), repr(i32))]
 pub enum CertificateType {
     Default = sys::rtcCertificateType_RTC_CERTIFICATE_DEFAULT,
     ECDSA = sys::rtcCertificateType_RTC_CERTIFICATE_ECDSA,
@@ -148,8 +161,8 @@ pub enum CertificateType {
 }
 
 #[derive(Debug, PartialEq, Clone, Copy)]
-#[cfg_attr(not(target_os = "windows"), repr(u32))]
-#[cfg_attr(target_os = "windows", repr(i32))]
+#[cfg_attr(any(not(target_os = "windows"), target_env = "gnu"), repr(u32))]
+#[cfg_attr(all(target_os = "windows", not(target_env = "gnu")), repr(i32))]
 pub enum TransportPolicy {
     All = sys::rtcTransportPolicy_RTC_TRANSPORT_POLICY_ALL,
     Relay = sys::rtcTransportPolicy_RTC_TRANSPORT_POLICY_RELAY,
