@@ -1,5 +1,4 @@
 use std::collections::{HashMap, HashSet};
-use std::env;
 use std::sync::{Arc, Mutex};
 use std::time::Duration;
 
@@ -10,6 +9,11 @@ use futures_util::{future, pin_mut, select, FutureExt, StreamExt};
 use serde::{Deserialize, Serialize};
 use uuid::Uuid;
 
+#[cfg(feature = "log")]
+use log as logger;
+#[cfg(feature = "tracing")]
+use tracing as logger;
+
 // use async_std::future::timeout;
 // use async_std::net::{TcpListener, TcpStream};
 // use async_std::task::spawn;
@@ -63,7 +67,7 @@ async fn handle_new_peer(peers: PeerMap, stream: TcpStream) {
         match Uuid::parse_str(tokens[1]) {
             Ok(uuid) => peer_id = Some(uuid),
             Err(err) => {
-                log::error!("Invalid uuid: {}", err);
+                logger::error!("Invalid uuid: {}", err);
                 *resp.status_mut() = StatusCode::BAD_REQUEST;
             }
         }
@@ -73,7 +77,7 @@ async fn handle_new_peer(peers: PeerMap, stream: TcpStream) {
     let websocket = match accept_hdr_async(stream, callback).await {
         Ok(websocket) => websocket,
         Err(err) => {
-            log::error!("WebSocket handshake failed: {}", err);
+            logger::error!("WebSocket handshake failed: {}", err);
             return;
         }
     };
@@ -82,7 +86,7 @@ async fn handle_new_peer(peers: PeerMap, stream: TcpStream) {
         None => return,
         Some(peer_id) => peer_id,
     };
-    log::info!("Peer {} connected", &peer_id);
+    logger::info!("Peer {} connected", &peer_id);
 
     let (outgoing, mut incoming) = websocket.split();
     let (tx_ws, rx_ws) = chan::unbounded();
@@ -100,22 +104,22 @@ async fn handle_new_peer(peers: PeerMap, stream: TcpStream) {
             let mut peer_msg = match serde_json::from_slice::<ConnectionMsg>(&msg.into_data()) {
                 Ok(peer_msg) => peer_msg,
                 Err(err) => {
-                    log::error!("Invalid ConnectionMsg: {}", err);
+                    logger::error!("Invalid ConnectionMsg: {}", err);
                     continue;
                 }
             };
-            log::info!("Peer {} << {:?}", &peer_id, &peer_msg);
+            logger::info!("Peer {} << {:?}", &peer_id, &peer_msg);
 
             let dest_id = peer_msg.dest_id;
 
             match peers.lock().unwrap().get_mut(&dest_id) {
                 Some(dest_peer) => {
                     peer_msg.dest_id = peer_id;
-                    log::info!("Peer {} >> {:?}", &dest_id, &peer_msg);
+                    logger::info!("Peer {} >> {:?}", &dest_id, &peer_msg);
                     let peer_msg = serde_json::to_vec(&peer_msg).unwrap();
                     dest_peer.try_send(Message::binary(peer_msg)).ok();
                 }
-                _ => log::warn!("Peer {} not found in server", &dest_id),
+                _ => logger::warn!("Peer {} not found in server", &dest_id),
             }
         }
     };
@@ -123,7 +127,7 @@ async fn handle_new_peer(peers: PeerMap, stream: TcpStream) {
     pin_mut!(dispatch, reply);
     future::select(dispatch, reply).await;
 
-    log::info!("Peer {} disconnected", &peer_id);
+    logger::info!("Peer {} disconnected", &peer_id);
     peers.lock().unwrap().remove(&peer_id);
 }
 
@@ -214,7 +218,7 @@ impl PeerConnectionHandler for WsConn {
     }
 
     fn on_data_channel(&mut self, mut dc: Box<RtcDataChannel<DataPipe>>) {
-        log::info!(
+        logger::info!(
             "Received Datachannel with: label={}, protocol={:?}, reliability={:?}",
             dc.label(),
             dc.protocol(),
@@ -248,7 +252,7 @@ async fn run_client(peer_id: Uuid, input: chan::Receiver<Uuid>, output: chan::Se
             Ok(dest_id) if dest_id != peer_id => dest_id,
             Err(_) | Ok(_) => return,
         };
-        log::info!("Peer {:?} sends data", &peer_id);
+        logger::info!("Peer {:?} sends data", &peer_id);
 
         let pipe = DataPipe::new_receiver(output.clone());
         let conn = WsConn::new(peer_id, dest_id, pipe, tx_ws.clone());
@@ -287,7 +291,7 @@ async fn run_client(peer_id: Uuid, input: chan::Receiver<Uuid>, output: chan::Se
             let peer_msg = match serde_json::from_slice::<ConnectionMsg>(&msg.into_data()) {
                 Ok(peer_msg) => peer_msg,
                 Err(err) => {
-                    log::error!("Invalid ConnectionMsg: {}", err);
+                    logger::error!("Invalid ConnectionMsg: {}", err);
                     continue;
                 }
             };
@@ -300,7 +304,7 @@ async fn run_client(peer_id: Uuid, input: chan::Receiver<Uuid>, output: chan::Se
                     MsgKind::Description(SessionDescription { sdp_type, .. })
                         if matches!(sdp_type, SdpType::Offer) =>
                     {
-                        log::info!("Client {:?} answering to {:?}", &peer_id, &dest_id);
+                        logger::info!("Client {:?} answering to {:?}", &peer_id, &dest_id);
 
                         let pipe = DataPipe::new_receiver(output.clone());
                         let conn = WsConn::new(peer_id, dest_id, pipe, tx_ws.clone());
@@ -310,7 +314,7 @@ async fn run_client(peer_id: Uuid, input: chan::Receiver<Uuid>, output: chan::Se
                         locked.get_mut(&dest_id).unwrap()
                     }
                     _ => {
-                        log::warn!("Peer {} not found in client", &dest_id);
+                        logger::warn!("Peer {} not found in client", &dest_id);
                         continue;
                     }
                 },
@@ -339,8 +343,22 @@ async fn run_client(peer_id: Uuid, input: chan::Receiver<Uuid>, output: chan::Se
 // #[async_std::test]
 #[tokio::test]
 async fn test_connectivity() {
-    env::set_var("RUST_LOG", "info");
-    let _ = env_logger::try_init();
+    #[cfg(feature = "tracing")]
+    {
+        tracing::subscriber::set_global_default(
+            tracing_subscriber::FmtSubscriber::builder()
+                .with_max_level(tracing::Level::INFO)
+                .finish(),
+        )
+        .ok();
+
+        datachannel::configure_logging(tracing::Level::INFO);
+    }
+    #[cfg(feature = "log")]
+    {
+        std::env::set_var("RUST_LOG", "info");
+        let _ = env_logger::try_init();
+    }
 
     let id1 = Uuid::new_v4();
     let id2 = Uuid::new_v4();
